import utils from '@/static/utils/utils.js';
import consts from '@/static/utils/consts.js';

const tasks = () => {
	let taskList = utils.getStorage(consts.STORAGE_USER_TASK_FOR_BROWSE) || []
	let dateNow = Date.now() // 当前时间戳
	// 过滤已经过期的任务
	taskList = taskList.filter(item => {
		// expires_date 如果为null 就表示长期任务
		if(item.expires_date) {
			// expires_date 且只有y-m-d 所以需要拼接时分秒～～～～～
			return dateNow < new Date(`${item.expires_date.replace(/-/g, '/')} 23:59:59`).getTime()
		} else {
			return true
		}
	})
	return taskList
}

const addTask = (task) => {
	const _tasks = tasks()
	const _aTask = _tasks.find((_task) => {
		return _task.id == task.id
	})
	if (_aTask) return
	_tasks.push(task)
	saveTasks(_tasks)
}

const updateTask = (task) => {
	const _tasks = tasks()
	for (let i = 0; i < _tasks.length; i++) {
		let aTask = _tasks[i]
		aTask.progress = task.id == aTask.id ? task.progress : 0
	}
	saveTasks(_tasks)
}

const resetTask = (task) => {
	const _tasks = tasks()
	for (let i = 0; i < _tasks.length; i++) {
		let aTask = _tasks[i]
		aTask.progress = 0
	}
	saveTasks(_tasks)
}

const removeTask = (task) => {
	const _tasks = tasks()
	if (_tasks.length == 0) return
	let idx = -1
	for (let i = 0; i < _tasks.length; i++) {
		if (task.id == _tasks[i].id) {
			idx = i
		}
	}	
	if (idx == -1) return
	_tasks.splice(idx, 1)
	saveTasks(_tasks)
}

const clearTask = () => {
	saveTasks([])
}

const saveTasks = (tasks) => {
	utils.setStorage(consts.STORAGE_USER_TASK_FOR_BROWSE, tasks)
}

module.exports = {
	tasks,
	addTask,
	updateTask,
	resetTask,
	removeTask,
	clearTask,
	saveTasks
}
