import sysApi from '@/api/system.js';

const check = (param = {}) => {
	param = Object.assign({
		title: "检测到有新版本！",
		content: "请升级app到最新版本！",
		canceltext: "暂不升级",
		oktext: "立即升级",
		barbackground: "rgba(50, 50, 50, 0.8)",
		barbackgroundactive: "rgba(32, 165, 58, 1)"
	}, param)
	const showLoading = param.showLoading || false
	sysApi.get_version({}, {
			showLoading,
			loadingTitle: '检查中...',
			showToast: false
		})
		.then(res => {
			plus.runtime.getProperty(plus.runtime.appid, (info) => {
				const needUpdate = res.data.digital_version > info.versionCode
				if (needUpdate) {
					const forceUpdate = res.data.is_force_update == 1
					const packageUrl = res.data.upload_url
					uni.showModal({
						title: param.title,
						content: param.content,
						showCancel: forceUpdate ? false : true,
						confirmText: param.oktext,
						cancelText: param.canceltext,
						success: (handler) => {
							if (!handler.confirm) return
							// 如果是热更新
							if (/\.wgt$/i.test(packageUrl)) {
								downloadPackage(packageUrl, param)
							} else {
								if (uni.getSystemInfoSync().platform == "android") {
									plus.runtime.openURL(packageUrl)
								} else if (uni.getSystemInfoSync().platform == "ios") {
									plus.runtime.openURL('https://apps.apple.com/cn/app/%E5%85%83%E8%B1%A1%E6%98%9F%E7%90%83/id1658261357')
								}
							}
						}
					})
				}
			})
		})
		.catch(() => {})
}

const downloadPackage = (url, param) => {		
	const dTask = uni.downloadFile({
		url: url,
		success: (wgt) => {
			if (wgt.statusCode == 200) {
				plus.runtime.install(wgt.tempFilePath, {
					force: true
				}, () => {
					plus.runtime.restart()
				}, (e) => {
					uni.showToast({
						title: '安装升级包失败:' + JSON.stringify(e),
						icon: 'none'
					})
				})
			} else {
				plus.nativeUI.alert("下载升级包失败，请手动去站点下载安装，错误码: " + wgt.statusCode);
			}
		},
		fail: () => { 
			plus.nativeUI.alert("下载升级包失败，请联系客服");
		}
	})

	const wrapwidth = parseInt(plus.screen.resolutionWidth);
	const bottom = uni.getSystemInfoSync().safeAreaInsets.bottom;
	const view = new plus.nativeObj.View("maskView", {
		backgroundColor: param.barbackground,
		left:  "0px",
		bottom: bottom + "px",
		width: wrapwidth + "px",
		height: "4px"
	})
	view.show()

	const viewinner = new plus.nativeObj.View("maskViewinner", {
		backgroundColor: param.barbackgroundactive,
		left:  "0px",
		bottom: bottom + "px",
		width: "1px",
		height: "4px"
	})
	viewinner.show()
	
	dTask.onProgressUpdate((wgt) => {
		viewinner.setStyle({
			width: parseInt(wgt.progress / 100 * wrapwidth) + 'px'
		})
	})
}


module.exports = {
	check
}
