/**
 * 上传文件
 */
function upload(params) {
	return new Promise((resolve, reject) => {
		uni.showLoading({
			title: '上传中...',
			icon: 'none',
			mask: true
		})
		uni.request({
			url: params.upload_url,
			method: 'PUT',
			header: {
				'content-type': 'multipart/form-data',
			},
			data: uni.base64ToArrayBuffer(params.file.base64.replace(/^data:image\/\w+;base64,/, '')),
			success: (res) => {
				let data = {
					code: 0,
					msg: '上传成功',
					data: {
						download_url: params.download_url
					}
				}
				if (res.statusCode == 200) {
					uni.showToast({
						title: '上传成功',
						icon: 'none'
					})
					resolve(data)
				} else {
					uni.showToast({
						title: '上传失败',
						icon: 'none'
					})
					reject()
				}
			},
			fail: (err) => {
				reject(err)
			},
			complete: () => {
				uni.hideLoading()
			}
		})
	})
}

function pathToBase64(path) {
	return new Promise((resolve, reject) => {
		plus.io.resolveLocalFileSystemURL(path, (entry) => {
			entry.file((file) => {
				let fileReader = new plus.io.FileReader()
				fileReader.onload = (evt) => {
					resolve({
						base64: evt.target.result,
						origin: file
					})
				}
				fileReader.onerror = (error) => {
					reject(error)
				}
				fileReader.readAsDataURL(file)
			}, (error) => {
				reject(error)
			})
		}, (error) => {
			reject(error)
		})
	})
}

module.exports = {
	upload,
	pathToBase64
}
